@@ -14,14 +14,14 @@
 #  limitations under the License.
 #
 
-from pipeline.param.hetero_sshe_lr_param import LogisticRegressionParam
+from pipeline.param.hetero_sshe_lr_param import HeteroSSHELRParam
 from pipeline.component.component_base import FateComponent
 from pipeline.interface import Input
 from pipeline.interface import Output
 from pipeline.utils.logger import LOGGER
 
 
-class HeteroSSHELR(FateComponent, LogisticRegressionParam):
+class HeteroSSHELR(FateComponent, HeteroSSHELRParam):
     def __init__(self, **kwargs):
         FateComponent.__init__(self, **kwargs)
 
@@ -30,9 +30,7 @@ class HeteroSSHELR(FateComponent, LogisticRegressionParam):
 
         new_kwargs = self.erase_component_base_param(**kwargs)
 
-        LogisticRegressionParam.__init__(self, **new_kwargs)
+        HeteroSSHELRParam.__init__(self, **new_kwargs)
         self.input = Input(self.name, data_type="multi")
         self.output = Output(self.name)
         self._module_name = "HeteroSSHELR"
-
-
