@@ -205,7 +205,7 @@ class HeteroNNParam(BaseParam):
             raise ValueError("use_first_metric_only should be a boolean")
 
         if self.floating_point_precision is not None and \
-                (not isinstance(self.floating_point_precision, int) or \
+                (not isinstance(self.floating_point_precision, int) or
                  self.floating_point_precision < 0 or self.floating_point_precision > 64):
             raise ValueError("floating point precision should be null or a integer between 0 and 64")
 
